==> va416xx-0.1.0.crate: va416xx-0.1.0/src/irq_router/irq_out3.rs <==
#[doc = "Register `IRQ_OUT3` reader"]
pub struct R(crate::R<IRQ_OUT3_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<IRQ_OUT3_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<IRQ_OUT3_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<IRQ_OUT3_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Field `IRQ_OUT3` reader - IRQ_OUT\\[127:96\\]"]
pub struct IRQ_OUT3_R(crate::FieldReader<u32, u32>);
impl IRQ_OUT3_R {
    #[inline(always)]
    pub(crate) fn new(bits: u32) -> Self {
        IRQ_OUT3_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for IRQ_OUT3_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl R {
    #[doc = "Bits 0:31 - IRQ_OUT\\[127:96\\]"]
    #[inline(always)]
    pub fn irq_out3(&self) -> IRQ_OUT3_R {
        IRQ_OUT3_R::new((self.bits & 0xffff_ffff) as u32)
    }
}
#[doc = "DEBUG IRQ_OUT\\[127:96\\]\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [irq_out3](index.html) module"]
pub struct IRQ_OUT3_SPEC;
impl crate::RegisterSpec for IRQ_OUT3_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [irq_out3::R](R) reader structure"]
impl crate::Readable for IRQ_OUT3_SPEC {
    type Reader = R;
}
#[doc = "`reset()` method sets IRQ_OUT3 to value 0"]
impl crate::Resettable for IRQ_OUT3_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> va416xx-0.1.1.crate: va416xx-0.1.1/src/irq_router/irq_out3.rs <==
#[doc = "Register `IRQ_OUT3` reader"]
pub struct R(crate::R<IRQ_OUT3_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<IRQ_OUT3_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<IRQ_OUT3_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<IRQ_OUT3_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Field `IRQ_OUT3` reader - IRQ_OUT\\[127:96\\]"]
pub struct IRQ_OUT3_R(crate::FieldReader<u32, u32>);
impl IRQ_OUT3_R {
    #[inline(always)]
    pub(crate) fn new(bits: u32) -> Self {
        IRQ_OUT3_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for IRQ_OUT3_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl R {
    #[doc = "Bits 0:31 - IRQ_OUT\\[127:96\\]"]
    #[inline(always)]
    pub fn irq_out3(&self) -> IRQ_OUT3_R {
        IRQ_OUT3_R::new(self.bits as u32)
    }
}
#[doc = "DEBUG IRQ_OUT\\[127:96\\]\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [irq_out3](index.html) module"]
pub struct IRQ_OUT3_SPEC;
impl crate::RegisterSpec for IRQ_OUT3_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [irq_out3::R](R) reader structure"]
impl crate::Readable for IRQ_OUT3_SPEC {
    type Reader = R;
}
#[doc = "`reset()` method sets IRQ_OUT3 to value 0"]
impl crate::Resettable for IRQ_OUT3_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
